@@ -2,9 +2,11 @@
 # =============================================================================
 # Copyright (c) 2004, 2006 Sean C. Gillies
 # Copyright (c) 2005 Nuxeo SARL <http://nuxeo.com>
+# Copyright (c) 2025 Tom Kralidis
 #
 # Authors : Sean Gillies <sgillies@frii.com>
 #           Julien Anguenot <ja@nuxeo.com>
+#           Tom Kralidis <tomkralidis@gmail.com>
 #
 # Contact email: sgillies@frii.com
 # =============================================================================
@@ -20,15 +22,14 @@ from math import sqrt
 from owslib.etree import etree
 from owslib.util import (openURL, ServiceException, testXMLValue,
                          extract_xml_list, xmltag_split, OrderedDict, nspath,
-                         nspath_eval, bind_url, Authentication)
+                         nspath_eval, bind_url, Authentication, str2bool)
 from owslib.fgdc import Metadata
 from owslib.iso import MD_Metadata
+from owslib.iso3 import MD_Metadata as MD_Metadata3  # ISO 19115 Part 3 XML
 from owslib.crs import Crs
 from owslib.namespaces import Namespaces
 from owslib.map.common import WMSCapabilitiesReader, AbstractContentMetadata
 
-from owslib.util import log
-
 n = Namespaces()
 WMS_NAMESPACE = n.get_namespace("wms")
 OGC_NAMESPACE = n.get_namespace('ogc')
@@ -69,7 +70,7 @@ class WebMapService_1_3_0(object):
         # Authentication handled by Reader
         reader = WMSCapabilitiesReader(
             self.version, url=self.url, headers=headers, auth=self.auth)
-        if xml:  # read from stored xml
+        if xml is not None:  # read from stored xml
             self._capabilities = reader.readString(xml)
         else:  # read from server
             self._capabilities = reader.read(self.url, timeout=self.timeout)
@@ -183,7 +184,7 @@ class WebMapService_1_3_0(object):
 
         # remapping the srs to crs for the request
         request['crs'] = str(srs)
-        request['bbox'] = ','.join([repr(x) for x in bbox])
+        request['bbox'] = ','.join([str(x) for x in bbox])
         request['format'] = str(format)
         request['transparent'] = str(transparent).upper()
         request['exceptions'] = str(exceptions)
@@ -447,7 +448,7 @@ class ContentMetadata(AbstractContentMetadata):
         self.id = self.name = testXMLValue(elem.find(nspath('Name', WMS_NAMESPACE)))
 
         # layer attributes
-        self.queryable = int(elem.attrib.get('queryable', 0))
+        self.queryable = int(str2bool(elem.attrib.get('queryable', '0')))
         self.cascaded = int(elem.attrib.get('cascaded', 0))
         self.opaque = int(elem.attrib.get('opaque', 0))
         self.noSubsets = int(elem.attrib.get('noSubsets', 0))
@@ -585,8 +586,6 @@ class ContentMetadata(AbstractContentMetadata):
             title = s.find(nspath('Title', WMS_NAMESPACE))
             if name is None and title is None:
                 raise ValueError('%s missing name and title' % (s,))
-            if name is None or title is None:
-                warnings.warn('%s missing name or title' % (s,))
             title_ = title.text if title is not None else name.text
             name_ = name.text if name is not None else title.text
             style = {'title': title_}
@@ -704,11 +703,23 @@ class ContentMetadata(AbstractContentMetadata):
                         metadataUrl['metadata'] = Metadata(mdelem)
                         continue
 
-                    mdelem = doc.find('.//' + nspath_eval('gmd:MD_Metadata', n.get_namespaces(['gmd']))) \
-                        or doc.find('.//' + nspath_eval('gmi:MI_Metadata', n.get_namespaces(['gmi'])))
+                    mdelem = doc.find(
+                        './/' + nspath_eval('gmd:MD_Metadata', n.get_namespaces(['gmd']))
+                    )
+                    if mdelem is None:
+                        doc.find(
+                            './/' + nspath_eval('gmi:MI_Metadata', n.get_namespaces(['gmi']))
+                        )
+
                     if mdelem is not None:
                         metadataUrl['metadata'] = MD_Metadata(mdelem)
                         continue
+                    else:
+                        mdelem = MD_Metadata3.find_start(doc)
+                        if mdelem is not None:
+                            metadataUrl["metadata"] = MD_Metadata3(mdelem)
+                        else:
+                            metadataUrl["metadata"] = None
                 except Exception:
                     metadataUrl['metadata'] = None
 
